package com.hzya.frame.seeyon.util;

import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpRequest;
import cn.hutool.http.HttpUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.hzya.frame.seeyon.entity.CtpFileEntity;
import com.hzya.frame.sysnew.application.api.entity.SysApplicationApiEntity;
import com.hzya.frame.sysnew.application.api.service.ISysApplicationApiService;
import com.hzya.frame.web.exception.BaseSystemException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.io.File;
import java.util.HashMap;

/**
 * @Description 致远rest接口工具类
 * @Author xiangerlin
 * @Date 2024/6/17 15:49
 **/
@Component
public class RestUtil {

    @Autowired
    private ISysApplicationApiService sysApplicationApiService;
    static Logger logger = LoggerFactory.getLogger(RestUtil.class);

    private RestUtil() {
    }


    /**
     * 附件上传
     * @param file 附件对象
     * @param api_code 接口编码
     * @return
     */
    public  JSONObject fileUpload(File file,String api_code) {
        if (StrUtil.isNotEmpty(api_code)){
            //1、查询附件上传api接口信息
            SysApplicationApiEntity sysApp = getByCode(api_code);
            if (null != sysApp){
                String app_url = sysApp.getAppUrl();
                String url = app_url+"/seeyon/rest/attachment?token=@token@";
                String token = getToken(null,"8000240000");
                url = url.replaceAll("@token@",token);
                HashMap<String, Object> paramMap = new HashMap<>();
                paramMap.put("file", file);
                String result = HttpUtil.post(url, paramMap);
                if (StrUtil.isNotBlank(result)) {
                    logger.info("附件上传结果"+result);
                    JSONObject jsonObject = JSONObject.parseObject(result);
                    String atts = jsonObject.get("atts").toString();
                    if (StrUtil.isNotEmpty(atts)) {
                        JSONArray jsonArray = JSONArray.parseArray(atts);
                        JSONObject res = (JSONObject) jsonArray.get(0);
                        return res;
                    }
                }
            }
        }else {
            throw new BaseSystemException("api_code不能为空");
        }
        return null;
    }

    /**
     * 获取token
     * @param login_name
     * @param api_code
     * @return
     */
    public  String getToken(String login_name,String api_code){
        if (StrUtil.isNotEmpty(api_code)){
            SysApplicationApiEntity sysApp = getByCode(api_code);
            if (null != sysApp){
                HashMap<String, String> hashMap = new HashMap<>();
                String app_url = sysApp.getAppUrl();
                String url = app_url+"/seeyon/rest/token";
                String headerIn = sysApp.getHeaderIn();
                JSONArray headers = JSON.parseArray(headerIn);
                for (int i = 0; i < headers.size(); i++) {
                    JSONObject object1 = headers.getJSONObject(i);
                    String parameterName = object1.getString("parameterName");
                    if ("userName".equals(parameterName) || "password".equals(parameterName) || "loginName".equals(parameterName)){
                        String example = object1.getString("example");
                        hashMap.put(parameterName,example);
                    }
                }
                if (StrUtil.isNotEmpty(login_name)){
                    hashMap.put("loginName",login_name);
                }
                String result = HttpRequest.post(url).body(JSON.toJSONString(hashMap)).execute().body();
                JSONObject jsonObject = JSONObject.parseObject(result);
                if (null != jsonObject) {
                    logger.info("======token：{}======" ,jsonObject.getString("id"));
                    return jsonObject.getString("id");
                }
            }
        }else {
            throw new BaseSystemException("api_code不能为空");
        }
        return null;
    }

    private SysApplicationApiEntity getByCode(String api_code){
        if (StrUtil.isNotEmpty(api_code)){
            SysApplicationApiEntity sysApp = new SysApplicationApiEntity();
            sysApp.setApiCode(Long.valueOf(api_code));
            sysApp = sysApplicationApiService.queryOne(sysApp);
            if (null != sysApp && StrUtil.isNotEmpty(sysApp.getId())){
                sysApp = sysApplicationApiService.get(sysApp.getId());
                if (null != sysApp){
                    return sysApp;
                }
            }
        }else {
            throw new BaseSystemException("api_code不能为空");
        }
        return null;
    }
}
